@@ -528,6 +528,7 @@ pyorbit_add_imethods_to_stub(PyObject *stub, ORBit_IMethods *imethods)
     tp_dict = ((PyTypeObject *)stub)->tp_dict;
     for (i = 0; i < imethods->_length; i++) {
 	PyCORBA_Method *meth;
+	gchar *pyname;
 
 	meth = PyObject_NEW(PyCORBA_Method, &PyCORBA_Method_Type);
 	if (!meth)
@@ -535,7 +536,9 @@ pyorbit_add_imethods_to_stub(PyObject *stub, ORBit_IMethods *imethods)
 	Py_INCREF(stub);
 	meth->meth_class = stub;
 	meth->imethod = &imethods->_buffer[i];
-	PyDict_SetItemString(tp_dict, meth->imethod->name, (PyObject *)meth);
+	pyname = _pyorbit_escape_name(meth->imethod->name);
+	PyDict_SetItemString(tp_dict, pyname, (PyObject *)meth);
+	g_free(pyname);
 	Py_DECREF(meth);
     }
 
@@ -561,7 +564,11 @@ pyorbit_add_imethods_to_stub(PyObject *stub, ORBit_IMethods *imethods)
 					"OOOs", fget, fset ? fset : Py_None,
 					Py_None, name);
 	    g_free(name);
-	    PyDict_SetItemString(tp_dict, &imethod->name[5], property);
+
+	    name = _pyorbit_escape_name(&imethod->name[5]);
+	    PyDict_SetItemString(tp_dict, name, property);
+	    g_free(name);
+
 	    Py_DECREF(property);
 	    Py_DECREF(fget);
 	    Py_XDECREF(fset);
